@@ -11,10 +11,8 @@ from packaging.version import Version
 from packaging.version import parse as parse_version
 from rich import print
 
-from cognite_toolkit._cdf_tk.builders import get_loader
 from cognite_toolkit._cdf_tk.cdf_toml import CDFToml
 from cognite_toolkit._cdf_tk.constants import DOCKER_IMAGE_NAME
-from cognite_toolkit._cdf_tk.data_classes import ModuleDirectories
 from cognite_toolkit._cdf_tk.utils import iterate_modules, read_yaml_file, safe_read, safe_write
 from cognite_toolkit._version import __version__
 
@@ -52,40 +50,6 @@ class ManualChange(Change):
         return ""
 
 
-class SetKindOnFile(AutomaticChange):
-    """Adds the kind to the filename of all resource files.
-
-Before `your_file.yaml`:
-After `your_file.FileMetadata.yaml`:
-    """
-
-    deprecated_from = Version("0.4.0")
-    has_file_changes = True
-
-    def do(self) -> set[Path]:
-        module_directories = ModuleDirectories.load(self._organization_dir)
-        changed: set[Path] = set()
-        for module in module_directories:
-            for resource_folder, source_files in module.source_paths_by_resource_folder.items():
-                for source_file in source_files:
-                    if source_file.suffix not in {".yaml", ".yml"}:
-                        continue
-                    loader, _ = get_loader(source_file, resource_folder, force_pattern=True)
-                    if loader is None:
-                        print(f"Could not find loader for {source_file}")
-                        continue
-                    if source_file.stem.casefold().endswith(loader.kind.casefold()):
-                        continue
-                    new_name = source_file.with_name(f"{source_file.stem}.{loader.kind}{source_file.suffix}")
-                    source_file.rename(new_name)
-                    changed.add(source_file)
-                    for suffix in [".sql", ".csv", ".parquet"]:
-                        if (adjacent_file := source_file.with_suffix(suffix)).exists():
-                            adjacent_file.rename(new_name.with_suffix(suffix))
-                            changed.add(adjacent_file)
-
-        return changed
-
 
 class FixViewBasedLocationFilter(AutomaticChange):
     """The created view-based location filter has been fixed to be compatible with the CDF API.
