@@ -3,7 +3,6 @@ from collections.abc import Sequence
 from functools import partial
 from pathlib import Path
 
-from cognite.client.data_classes._base import T_CogniteResource
 from cognite.client.data_classes.data_modeling import (
     ViewId,
 )
@@ -14,12 +13,13 @@ from cognite_toolkit._cdf_tk.client import ToolkitClient
 from cognite_toolkit._cdf_tk.constants import DATA_MANIFEST_SUFFIX, DATA_RESOURCE_DIR
 from cognite_toolkit._cdf_tk.cruds import ViewCRUD
 from cognite_toolkit._cdf_tk.exceptions import ToolkitValueError
+from cognite_toolkit._cdf_tk.protocols import T_ResourceRequest, T_ResourceResponse
 from cognite_toolkit._cdf_tk.storageio import (
     T_Selector,
     UploadableStorageIO,
     get_upload_io,
 )
-from cognite_toolkit._cdf_tk.storageio._base import T_WriteCogniteResource, TableUploadableStorageIO, UploadItem
+from cognite_toolkit._cdf_tk.storageio._base import TableUploadableStorageIO, UploadItem
 from cognite_toolkit._cdf_tk.storageio.selectors import Selector, SelectorAdapter
 from cognite_toolkit._cdf_tk.storageio.selectors._instances import InstanceSpaceSelector
 from cognite_toolkit._cdf_tk.tk_warnings import HighSeverityWarning, MediumSeverityWarning
@@ -215,6 +215,10 @@ class UploadCommand(ToolkitCommand):
                 reader = MultiFileReader(datafiles)
                 if reader.is_table and not isinstance(io, TableUploadableStorageIO):
                     raise ToolkitValueError(f"{selector.display_name} does not support {reader.format!r} files.")
+
+                chunk_count = io.count_chunks(reader)
+                iteration_count = chunk_count // io.CHUNK_SIZE + (1 if chunk_count % io.CHUNK_SIZE > 0 else 0)
+
                 tracker = ProgressTracker[str]([self._UPLOAD])
                 executor = ProducerWorkerExecutor[list[tuple[str, dict[str, JsonVal]]], Sequence[UploadItem]](
                     download_iterable=io.read_chunks(reader, selector),
@@ -230,7 +234,7 @@ class UploadCommand(ToolkitCommand):
                         tracker=tracker,
                         console=console,
                     ),
-                    iteration_count=None,
+                    iteration_count=iteration_count,
                     max_queue_size=self._MAX_QUEUE_SIZE,
                     download_description=f"Reading {selector.display_name!r} files",
                     process_description="Processing",
@@ -262,7 +266,7 @@ class UploadCommand(ToolkitCommand):
         self, selector: Selector, data_file: Path, client: ToolkitClient
     ) -> UploadableStorageIO | None:
         try:
-            io_cls = get_upload_io(type(selector))
+            io_cls = get_upload_io(selector)
         except ValueError as e:
             self.warn(HighSeverityWarning(f"Could not find StorageIO for selector {selector}: {e}"))
             return None
@@ -271,9 +275,9 @@ class UploadCommand(ToolkitCommand):
     @classmethod
     def _upload_items(
         cls,
-        data_chunk: Sequence[UploadItem],
+        data_chunk: Sequence[UploadItem[T_ResourceRequest]],
         upload_client: HTTPClient,
-        io: UploadableStorageIO[T_Selector, T_CogniteResource, T_WriteCogniteResource],
+        io: UploadableStorageIO[T_Selector, T_ResourceResponse, T_ResourceRequest],
         selector: T_Selector,
         dry_run: bool,
         tracker: ProgressTracker[str],
