@@ -17,8 +17,8 @@ class Plugin:
 class Plugins(Enum):
     run = Plugin("run", "plugin for Run command to execute Python scripts in CDF")
     dump = Plugin("dump", "plugin for Dump command to retrieve Asset resources from CDF")
-    purge = Plugin("purge", "plugin for Purge command to remove datasets and spaces from CDF")
     dev = Plugin("dev", "plugin for commands to develop modules in CDF")
+    data = Plugin("data", "plugin for Data command to manage data in CDF")
 
     @staticmethod
     def list() -> dict[str, bool]:
