@@ -7,7 +7,9 @@ from ._base import DataSelector
 from ._canvas import CanvasExternalIdSelector, CanvasSelector
 from ._charts import AllChartsSelector, ChartExternalIdSelector, ChartOwnerSelector, ChartSelector
 from ._datapoints import (
+    DataPointsDataSetSelector,
     DataPointsFileSelector,
+    DataPointsSelector,
     ExternalIdColumn,
     InstanceColumn,
     InternalIdColumn,
@@ -40,6 +42,7 @@ Selector = Annotated[
     | AssetSubtreeSelector
     | AssetCentricFileSelector
     | DataSetSelector
+    | DataPointsDataSetSelector
     | DataPointsFileSelector
     | ChartExternalIdSelector
     | CanvasExternalIdSelector
@@ -62,7 +65,9 @@ __all__ = [
     "ChartExternalIdSelector",
     "ChartOwnerSelector",
     "ChartSelector",
+    "DataPointsDataSetSelector",
     "DataPointsFileSelector",
+    "DataPointsSelector",
     "DataSelector",
     "DataSetSelector",
     "ExternalIdColumn",
