@@ -115,6 +115,13 @@ class RequestMessage(HTTPMessage):
 @dataclass
 class SuccessResponse(ResponseMessage):
     body: str
+    content: bytes
+
+    def dump(self) -> dict[str, JsonVal]:
+        output = super().dump()
+        # We cannot serialize bytes, so we indicate its presence instead
+        output["content"] = "<bytes>" if self.content else None
+        return output
 
 
 @dataclass
@@ -134,7 +141,7 @@ class SimpleRequest(RequestMessage):
 
     @classmethod
     def create_success_response(cls, response: httpx.Response) -> Sequence[ResponseMessage]:
-        return [SuccessResponse(status_code=response.status_code, body=response.text)]
+        return [SuccessResponse(status_code=response.status_code, body=response.text, content=response.content)]
 
     @classmethod
     def create_failure_response(cls, response: httpx.Response) -> Sequence[HTTPMessage]:
@@ -309,7 +316,11 @@ class ItemsRequest(Generic[T_COVARIANT_ID], BodyRequest):
 
     def create_success_response(self, response: httpx.Response) -> Sequence[HTTPMessage]:
         ids = [item.as_id() for item in self.items]
-        return [SuccessResponseItems(status_code=response.status_code, ids=ids, body=response.text)]
+        return [
+            SuccessResponseItems(
+                status_code=response.status_code, ids=ids, body=response.text, content=response.content
+            )
+        ]
 
     def create_failure_response(self, response: httpx.Response) -> Sequence[HTTPMessage]:
         error = ErrorDetails.from_response(response)
@@ -369,7 +380,11 @@ class ResponseList(UserList[ResponseMessage | FailedRequestMessage]):
         results: list[ResponseMessage | FailedRequestMessage] = []
         for message in self.data:
             if isinstance(message, SuccessResponse):
-                results.append(SuccessResponseItems(status_code=message.status_code, ids=[item_id], body=message.body))
+                results.append(
+                    SuccessResponseItems(
+                        status_code=message.status_code, content=message.content, ids=[item_id], body=message.body
+                    )
+                )
             elif isinstance(message, FailedResponse):
                 results.append(
                     FailedResponseItems(
