@@ -158,7 +158,11 @@ from cognite_toolkit._cdf_tk.client.data_classes.graphql_data_models import (
     GraphQLDataModelWrite,
     GraphQLDataModelWriteList,
 )
-from cognite_toolkit._cdf_tk.client.data_classes.infield import InfieldLocationConfig, InfieldLocationConfigList
+from cognite_toolkit._cdf_tk.client.data_classes.infield import (
+    InFieldCDMLocationConfig,
+    InfieldLocationConfig,
+    InfieldLocationConfigList,
+)
 from cognite_toolkit._cdf_tk.client.data_classes.location_filters import (
     LocationFilter,
     LocationFilterList,
@@ -855,6 +859,20 @@ API_RESOURCES = [
             ],
         },
     ),
+    APIResource(
+        api_name="infield.cdm_config",
+        resource_cls=InFieldCDMLocationConfig,
+        _write_cls=InFieldCDMLocationConfig,
+        # Todo: Remove these.
+        list_cls=InfieldLocationConfigList,
+        _write_list_cls=InfieldLocationConfigList,
+        methods={
+            "create": [Method(api_class_method="apply", mock_class_method="create_multiple")],
+            "retrieve": [
+                Method(api_class_method="retrieve", mock_class_method="return_values"),
+            ],
+        },
+    ),
     APIResource(
         api_name="streams",
         resource_cls=StreamResponse,
