@@ -26,6 +26,7 @@ from cognite_toolkit._cdf_tk.storageio.selectors import (
     CanvasExternalIdSelector,
     ChartExternalIdSelector,
     ChartOwnerSelector,
+    DataPointsDataSetSelector,
     DataPointsFileSelector,
     DataSelector,
     DataSetSelector,
@@ -264,6 +265,17 @@ def example_selector_data() -> Iterable[tuple]:
         FileContentIO.KIND,
         id="FileIdentifierSelector",
     )
+    yield pytest.param(
+        {
+            "type": "datapointsDataSet",
+            "dataSetExternalId": "my_datapoints_data_set",
+            "kind": "Datapoints",
+        },
+        DataPointsDataSetSelector,
+        DatapointsIO,
+        DatapointsIO.KIND,
+        id="DataPointsDataSetSelector",
+    )
 
 
 @pytest.fixture(scope="module")
